% Chebyshev function parameterization of log(radius) of a tubular bell
% @ Vipul Kakkad 11/27/2012

% This code takes coefficients, and returns an N-element log(radius) 
% function that corresponds to them.
function log_r_func = coeffs2logR_Chebyshev(N,Coeffs,showplots)
% Coeffs = M x 1 array of the first M coefficients
% N = 1 x 1 number of collocation points
% showplots = 1x1 logical of whether plots should be shown

Mcoeffs = numel(Coeffs);

[~,xvals] = cheb(N-1);

% start with vector of zeros
log_r_func = zeros(N,1);

% sum up Chebyshev functions scaled by the corresponding coefficients
for ind=1:Mcoeffs
    log_r_func = log_r_func + Coeffs(ind,1)*polyval(ChebyshevPoly(ind),xvals);
end

% plot radius function if asked for.
if(showplots==1)
    r_func = exp(log_r_func);
    hold on
    plot(xvals,r_func,'.-')
    drawnow
end

end