% Target function for Optimization of the Shape of Tubular Bells
% @ Vipul Kakkad 11/27/2012

% This code simulates a N-element Chebyshev-collocated  beam with the 
% radius function specified by the coefficients.
% Gives the log of the mean-square error in frequencies compared to the
% target frequencies.
function [error_val] = target_func(Coeffs,targets,N)
% Coeffs = M x 1 array of the first M coefficients
% targets = k x 1 array of the target freq. ratios to the first freq.
% N = 1 x 1 number of collocation points

k = length(targets);

% define log(radius) in terms of Chebyshev coefficients
log_r_func = coeffs2logR_Gaussian(N,Coeffs,0);

% find the eigenvalues
[eigenvals] = free_free_nonuniform(N, log_r_func, k+1, 0);
% (k+1) eigenvalues to get k ratios

% find RMS error
freqs = eigenvals.^2;
ratios = freqs(2:end,1)/freqs(1,1);
error_val =log10(sum((ratios - targets).^2));

end
